nbclient: A client library for executing notebooks. Formerly nbconvert's ExecutePreprocessor.
=============================================================================================

Description
-----------

A client library for executing notebooks. Formerly nbconvert's ExecutePreprocessor.

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/nbclient/

